@@ -144,10 +144,37 @@ namespace giac {
   gen genstabilityerr(GIAC_CONTEXT0);
 
   // short integer arithmetic
+#ifdef TICE
+  inline int absint(int a){
+    if (a<0)
+      return -a;
+    else
+      return a;
+  }
+
+  inline double absdouble(double a){
+    return std::fabs(a);
+  }
+
+  inline int giacmin(int a, int b){
+    if (a<b)
+      return a;
+    else
+      return b;
+  }
+
+  inline int giacmax(int a, int b){
+    if (a<b)
+      return b;
+    else
+      return a;
+  }
+#else
   int absint(int a);
   double absdouble(double a);
   int giacmin(int a,int b);
   int giacmax(int a,int b);
+#endif
   int invmod(int n,int modulo);
   unsigned invmod(unsigned a,int b);
   int invmod(longlong a,int b);
@@ -441,7 +468,11 @@ namespace giac {
   public:
     bool operator () (const gen & a,const gen & b) const;
   };
+#if 0 //def CPP11 // otherwise crash on A[1,1]:=1; A[1,2]:=2;
+  typedef std::map<gen,gen,std::function<bool(const gen &, const gen &)> > gen_map;
+#else
   typedef std::map<gen,gen,comparegen> gen_map;
+#endif
 #else
   typedef std::map<gen,gen,const std::pointer_to_binary_function < const gen &, const gen &, bool> > gen_map;
 #endif
@@ -901,8 +932,12 @@ namespace giac {
     gen_map m;
 #if 1 // def NSPIRE
     ref_gen_map(): ref_count(1),m() {}
+#else
+#ifdef CPP11
+     ref_gen_map(const std::function<bool(const gen &, const gen &)> & p): ref_count(1),m(p) {}
 #else
     ref_gen_map(const std::pointer_to_binary_function < const gen &, const gen &, bool> & p): ref_count(1),m(p) {}
+#endif // CPP11
 #endif
     ref_gen_map(const gen_map & M):ref_count(1),m(M) {}
   };
@@ -1445,7 +1480,7 @@ namespace giac {
 
   class identificateur {
   public:
-    int * ref_count;
+    int * ref_count_ptr;
     gen * value;
     // std::string * name;
     const char * id_name;
